@@ -22,14 +22,10 @@ Contact: yuvraaj@gmail.com
 #include "MainWindow.h"
 #include "PhoneNumberValidator.h"
 
-#include <phonon/AudioOutput>
-#include <phonon/AudioOutputDevice>
 #include <QDesktopServices>
 #include <iostream>
 using namespace std;
 
-extern QStringList arrLogFiles;
-
 MainWindow::MainWindow (QWidget *parent)
 : QDeclarativeView (parent)
 , gvApi (true, this)
@@ -119,127 +115,6 @@ MainWindow::~MainWindow ()
     dbMain.saveCookies (cookies);
 }//MainWindow::~MainWindow
 
-/** Initialize the log file name and timer.
- * The log timer is required to update the log view every 3 seconds.
- * The log cannot be updated every time a log is entered because the view MUST
- * be updated only in the GUI thread. The timer always runs in the context of
- * the main thread - which is the GUI thread.
- */
-void
-MainWindow::initLogging ()
-{
-    // Initialize logging
-    logsTimer.setSingleShot (true);
-    logsTimer.start (3 * 1000);
-    bool rv = connect (&logsTimer, SIGNAL(timeout()),
-                        this     , SLOT(onCleanupLogsArray()));
-    Q_ASSERT(rv); Q_UNUSED(rv);
-
-    setStatus("Using qgvdial version 0.3.888");
-}//MainWindow::initLogging
-
-/** Log information to console and to log file
- * This function is invoked from the qDebug handler that is installed in main.
- * @param strText Text to be logged
- */
-void
-MainWindow::log (const QDateTime & /*dt*/, int /*level*/, QString &strText)
-{
-    if (!strPass.isEmpty() && strText.contains(strPass)) {
-        strText.replace(strPass, "XXXXXX");
-    }
-
-    // Append it to the circular buffer
-    QMutexLocker locker(&logMutex);
-    arrLogMsgs.prepend (strText);
-    bKickLocksTimer = true;
-}//MainWindow::log
-
-void
-MainWindow::onCleanupLogsArray()
-{
-    int timeout = 3 * 1000;
-    do { // Begin cleanup block (not a loop)
-        QMutexLocker locker(&logMutex);
-        if (!bKickLocksTimer) {
-            break;
-        }
-        bKickLocksTimer = false;
-        timeout = 1 * 1000;
-
-        while (arrLogMsgs.size () > 50) {
-            arrLogMsgs.removeLast ();
-        }
-
-        QDeclarativeContext *ctx = this->rootContext();
-        ctx->setContextProperty ("g_logModel", QVariant::fromValue(arrLogMsgs));
-    } while (0); // End cleanup block (not a loop)
-
-    // Flush the log. flush it!
-    qgv_LogFlush ();
-
-    logsTimer.start (timeout);
-}//MainWindow::onCleanupLogsArray
-
-/** Status update function
- * Use this function to update the status. The status is shown dependent on the
- * platform. On Windows and Linux, this status is shown on the system tray as a
- * notification message from our systray icon. On Maemo, it is shown as the
- * notification banner.
- * @param strText Text to show as the status
- * @param timeout Timeout in milliseconds. 0 indicates a status that remains
- *          until the next status is to be displayed.
- */
-void
-MainWindow::setStatus(const QString &strText, int timeout /* = 3000*/)
-{
-    Q_WARN(strText);
-
-#ifdef Q_WS_MAEMO_5
-    infoBox.hide ();
-
-    // Show the banner only if the window is invisible. Otherwise the QML
-    // status bar is more than enough for this job.
-    if (!this->isVisible ()) {
-        QLabel *theLabel = (QLabel *) infoBox.widget ();
-        if (NULL == theLabel) {
-            theLabel = new QLabel (strText, &infoBox);
-            theLabel->setAlignment (Qt::AlignHCenter);
-            infoBox.setWidget (theLabel);
-            qDebug("Created the Maemo5 yellow banner label");
-        } else {
-            qDebug() << "Display the status banner:" << strText;
-            theLabel->setText (strText);
-        }
-        infoBox.setTimeout (0 == timeout ? 3000 : timeout);
-        infoBox.show ();
-    }
-#else
-    if (NULL != pSystray) {
-        pSystray->showMessage ("Status", strText,
-                               QSystemTrayIcon::Information,
-                               timeout);
-    }
-#endif
-
-    statusTimer.stop ();
-    QDeclarativeContext *ctx = this->rootContext();
-    ctx->setContextProperty ("g_strStatus", strText);
-
-    if (0 != timeout) {
-        statusTimer.setSingleShot (true);
-        statusTimer.setInterval (timeout);
-        statusTimer.start ();
-    }
-}//MainWindow::setStatus
-
-void
-MainWindow::onStatusTimerTick ()
-{
-    QDeclarativeContext *ctx = this->rootContext();
-    ctx->setContextProperty ("g_strStatus", "Ready");
-}//MainWindow::onStatusTimerTick
-
 /** Invoked when the QtSingleApplication sends a message
  * We have used a QtSingleApplication to ensure that there is only one instance
  * of our program running in a specific user context. When the user attempts to
@@ -297,6 +172,7 @@ MainWindow::init ()
     OsDependent &osd = Singletons::getRef().getOSD ();
     bool rv;
 
+    Q_DEBUG ("Initializing...");
     setStatus ("Initializing...");
 
     // Initialize the database: This may create OR blowup and then re-create
@@ -496,6 +372,8 @@ MainWindow::init ()
         // Login without popping up the "enter user/pass" dialog
         doLogin ();
     } else {
+        Q_DEBUG("No user and password set up. Asking user to enter that info");
+
         // Show this status for 60 seconds (or until the next status)
         setStatus ("Please enter email and password", 60 * 1000);
 
@@ -726,6 +604,7 @@ MainWindow::doLogin ()
         token->inParams["user"] = strUser;
         token->inParams["pass"] = strPass;
 
+        Q_DEBUG("Login using user ") << strUser;
         setStatus ("Logging in...", 0);
 
         osd.setLongWork (this, true);
@@ -798,16 +677,23 @@ MainWindow::loginCompleted (AsyncTaskToken *token)
         osd.setLongWork (this, false);
 
         setStatus ("User login failed", 30*1000);
-        QString strErr = gvApi.getLastErrorString ();
+
+        QString strErr;
+        if (token) {
+            strErr = token->errorString;
+        }
         if (strErr.isEmpty ()) {
             strErr = "User login failed";
         }
         this->showMsgBox (strErr);
 
+        Q_WARN("User login failed. Error string: ") << strErr;
+
         QTimer::singleShot (500, this, SLOT(onRecreateCookieJar()));
     } else {
         CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
         setStatus ("User logged in");
+        Q_DEBUG ("User logged in");
 
         QString strOldUser, strOldPass;
         dbMain.getUserPass (strOldUser, strOldPass);
@@ -891,6 +777,8 @@ MainWindow::logoutCompleted (AsyncTaskToken *token)
     ctx->setContextProperty ("g_bIsLoggedIn", bLoggedIn);
 
     setStatus ("Logout complete");
+    Q_DEBUG ("Logout complete");
+
     OsDependent &osd = Singletons::getRef().getOSD ();
     osd.setLongWork (this, false);
 
@@ -959,6 +847,7 @@ MainWindow::getContactsDone (bool bOk)
     if (!bOk) {
         this->showMsgBox ("Contacts retrieval failed");
         setStatus ("Contacts retrieval failed");
+        Q_WARN ("Contacts retrieval failed");
     }
 }//MainWindow::getContactsDone
 
@@ -993,403 +882,6 @@ MainWindow::deinitInbox ()
     oInbox.loggedOut ();
 }//MainWindow::deinitInbox
 
-/** Convert a number and a key to more info into a structure with all the info.
- * @param strNumber The phone number
- * @param strNameLink The key to the associated information. This parameter is
- *          optional. If it is not present, then a dummy structure is created
- *          that has only the number as valid information.
- */
-bool
-MainWindow::getInfoFrom (const QString &strNumber,
-                         const QString &strNameLink,
-                         ContactInfo &info)
-{
-    info.init ();
-
-    if (0 != strNameLink.size ())
-    {
-        CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
-        info.strId = strNameLink;
-
-        if (!dbMain.getContactFromLink (info))
-        {
-            this->showMsgBox ("Failed to get contact information");
-            return (false);
-        }
-
-        for (int i = 0; i < info.arrPhones.size (); i++)
-        {
-            QString lhs = strNumber;
-            QString rhs = info.arrPhones[i].strNumber;
-
-            GVApi::simplify_number (lhs);
-            GVApi::simplify_number (rhs);
-            if (lhs == rhs)
-            {
-                info.selected = i;
-                break;
-            }
-        }
-    }
-    else
-    {
-        info.strTitle = strNumber;
-        PhoneInfo num;
-        num.Type = PType_Unknown;
-        num.strNumber = strNumber;
-        info.arrPhones += num;
-        info.selected = 0;
-    }
-
-    return (true);
-}//MainWindow::getInfoFrom
-
-bool
-MainWindow::findInfo (const QString &strNumber, ContactInfo &info)
-{
-    bool rv = true;
-    info.init ();
-
-    QString strTrunc = strNumber;
-    GVApi::simplify_number (strTrunc, false);
-    strTrunc.remove(' ').remove('+');
-
-    CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
-    if (!dbMain.getContactFromNumber (strTrunc, info)) {
-        qDebug ("Could not find info about this number. Using dummy info");
-        info.strTitle = strNumber;
-        PhoneInfo num;
-        num.Type = PType_Unknown;
-        num.strNumber = strNumber;
-        info.arrPhones += num;
-        info.selected = 0;
-    } else {
-        // Found it, now set the "selected" field correctly
-        info.selected = 0;
-        foreach (PhoneInfo num, info.arrPhones) {
-            QString strNum = num.strNumber;
-            GVApi::simplify_number (strNum, false);
-            strNum.remove(' ').remove('+');
-
-            if (-1 != strNum.indexOf (strTrunc)) {
-                break;
-            }
-            info.selected++;
-        }
-
-        if (info.selected >= info.arrPhones.size ()) {
-            info.selected = 0;
-            rv = false;
-        }
-    }
-
-    return (rv);
-}//MainWindow::findInfo
-
-void
-MainWindow::dialNow (const QString &strTarget)
-{
-    CalloutInitiator *ci;
-    bool success = false;
-    DialContext *ctx = NULL;
-    AsyncTaskToken *token = NULL;
-
-    do { // Begin cleanup block (not a loop)
-        if (!bLoggedIn) {
-            setStatus ("User is not logged in yet. Cannot make any calls.");
-            break;
-        }
-        if (gvApi.getSelfNumber().isEmpty () ||
-           (gvApi.getSelfNumber() == "CLIENT_ONLY"))
-        {
-            Q_WARN("Self number is not valid. Dial canceled");
-            setStatus ("Account not configured");
-            showMsgBox ("Account not configured");
-            break;
-        }
-
-        QMutexLocker locker (&mtxDial);
-        if (bCallInProgress) {
-            setStatus ("Another call is in progress. Please try again later");
-            break;
-        }
-
-        GVRegisteredNumber gvRegNumber;
-        if (!getDialSettings (bDialout, gvRegNumber, ci)) {
-            setStatus ("Unable to dial because settings are not valid.");
-            break;
-        }
-
-        if (strTarget.isEmpty ()) {
-            setStatus ("Cannot dial empty number");
-            break;
-        }
-
-        QString strTest = strTarget;
-        strTest.remove(QRegExp ("\\d*"))
-               .remove(QRegExp ("\\s"))
-               .remove('+')
-               .remove('-');
-        if (!strTest.isEmpty ()) {
-            setStatus ("Cannot use numbers with special symbols or characters");
-            break;
-        }
-
-        ctx = new DialContext(gvApi.getSelfNumber(), strTarget, this);
-        if (NULL == ctx) {
-            setStatus ("Failed to dial out because of allocation problem");
-            break;
-        }
-        token = new AsyncTaskToken(this);
-        if (NULL == token) {
-            setStatus ("Failed to dial out because of allocation problem");
-            break;
-        }
-
-        ctx->token = token;
-        token->callerCtx = ctx;
-
-        success = connect (ctx , SIGNAL(sigDialComplete(DialContext*,bool)),
-                           this, SLOT(onSigDialComplete(DialContext*,bool)));
-        Q_ASSERT(success);
-        success = connect (token, SIGNAL(completed(AsyncTaskToken*)),
-                           this , SLOT(dialComplete(AsyncTaskToken*)));
-        Q_ASSERT(success);
-
-        token->inParams["destination"] = strTarget;
-
-        OsDependent &osd = Singletons::getRef().getOSD ();
-        osd.setLongWork (this, true);
-
-        bCallInProgress = true;
-        bDialCancelled = false;
-
-        ctx->showMsgBox ();
-
-        if (bDialout) {
-            ctx->ci = ci;
-
-            token->inParams["source"] = ci->selfNumber ();
-            success = gvApi.callOut (token);
-        } else {
-            token->inParams["source"] = gvRegNumber.strNumber;
-            token->inParams["sourceType"] = QString(gvRegNumber.chType);
-            success = gvApi.callBack (token);
-        }
-    } while (0); // End cleanup block (not a loop)
-
-    if (success) {
-        return;
-    }
-
-    if (ctx) {
-        ctx->deleteLater ();
-    }
-    if (token) {
-        token->deleteLater ();
-    }
-}//MainWindow::dialNow
-
-void
-MainWindow::onSigText (const QString &strNumbers, const QString &strText)
-{
-    QStringList arrNumbers;
-    arrNumbers = strNumbers.split (',');
-    sendSMS (arrNumbers, strText);
-}//MainWindow::onSigText
-
-//! Invoked by the DBus Text server
-/**
- * When the DBus Text server's text method is called, it finally reaches this
- * function. Here, we:
- * 1. Find out information (if there is any) about each number
- * 2. Add that info into the widget that collects numbers to send a text to
- * 3. Show the text widget
- */
-void
-MainWindow::onSendTextWithoutData (const QStringList &arrNumbers)
-{
-    do { // Begin cleanup block (not a loop)
-        QObject *pMainPage = this->getQMLObject ("MainPage");
-        if (NULL == pMainPage) {
-            Q_WARN("Could not get to MainPage");
-            break;
-        }
-
-        QObject *pSmsView = this->getQMLObject ("SmsPage");
-        if (NULL == pSmsView) {
-            Q_WARN("Could not get to SmsPage");
-            break;
-        }
-
-        foreach (QString strNumber, arrNumbers) {
-            if (strNumber.isEmpty ()) {
-                Q_WARN("Cannot text empty number");
-                continue;
-            }
-
-            ContactInfo info;
-
-            // Get info about this number
-            if (!findInfo (strNumber, info)) {
-                Q_WARN("Unable to find information for ") << strNumber;
-                continue;
-            }
-
-            QMetaObject::invokeMethod (pSmsView, "addSmsDestination",
-                Q_ARG (QVariant, QVariant(info.strTitle)),
-                Q_ARG (QVariant, QVariant(info.arrPhones[info.selected].strNumber)));
-        }
-
-        // Show the SMS View
-        QMetaObject::invokeMethod (pMainPage, "showSmsView");
-
-        // Show myself (because I may be hidden)
-        this->show ();
-    } while (0); // End cleanup block (not a loop)
-}//MainWindow::onSendTextWithoutData
-
-void
-MainWindow::onSigDialComplete (DialContext *ctx, bool ok)
-{
-    QMutexLocker locker (&mtxDial);
-    if (ok) {
-        if (!ctx->bDialOut) {
-            emit dialCanFinish ();
-        }
-    } else {
-        gvApi.cancel (ctx->token);
-    }
-}//MainWindow::onSigDialComplete
-
-void
-MainWindow::dialComplete (AsyncTaskToken *token)
-{
-    QMutexLocker locker (&mtxDial);
-    DialContext *ctx = (DialContext *) token->callerCtx;
-    bool bReleaseContext = true;
-
-    if (ATTS_SUCCESS != token->status) {
-        if (bDialCancelled) {
-            setStatus ("Cancelled dial out");
-        } else if (NULL == ctx->fallbackCi) {
-            // Not currently in fallback mode and there was a problem
-            // ... so start fallback mode
-            Q_DEBUG("Attempting fallback dial");
-            bReleaseContext = false;
-            fallbackDialout (ctx);
-        } else {
-            setStatus ("Dialing failed", 10*1000);
-            this->showMsgBox (gvApi.getLastErrorString ());
-        }
-    } else {
-        bool success = false;
-        do { // Begin cleanup block (not a loop)
-            if (!bDialout) {
-                success = true;
-                break;
-            }
-
-            if (NULL == ctx) {
-                Q_WARN("Invalid call out context");
-                break;
-            }
-
-            if (NULL == ctx->ci) {
-                Q_WARN("Invalid call out initiator");
-                break;
-            }
-
-            QString accessNumber = token->outParams["access_number"].toString();
-            if (accessNumber.isEmpty ()) {
-                Q_WARN("Invalid access number");
-                break;
-            }
-
-            ctx->ci->initiateCall (accessNumber);
-            setStatus ("Callout in progress");
-
-            success = true;
-        } while (0); // End cleanup block (not a loop)
-
-        if (success) {
-            setStatus (QString("Dial successful to %1.")
-                       .arg(token->inParams["destination"].toString()));
-        } else {
-            setStatus ("Callout failed");
-        }
-    }
-    bCallInProgress = false;
-
-    OsDependent &osd = Singletons::getRef().getOSD ();
-    osd.setLongWork (this, false);
-
-    if (bReleaseContext) {
-        ctx->deleteLater ();
-    }
-
-    token->deleteLater ();
-}//MainWindow::dialComplete
-
-void
-MainWindow::sendSMS (const QStringList &arrNumbers, const QString &strText)
-{
-    QStringList arrFailed;
-    QString msg;
-    AsyncTaskToken *token;
-
-    for (int i = 0; i < arrNumbers.size (); i++)
-    {
-        if (arrNumbers[i].isEmpty ()) {
-            Q_WARN("Cannot text empty number");
-            continue;
-        }
-
-        token = new AsyncTaskToken(this);
-        if (!token) {
-            Q_WARN("Allocation failure");
-            break;
-        }
-
-        token->inParams["destination"] = arrNumbers[i];
-        token->inParams["text"] = strText;
-
-        if (!gvApi.sendSms (token)) {
-            arrFailed += arrNumbers[i];
-            msg = QString ("Failed to send an SMS to %1").arg (arrNumbers[i]);
-            Q_WARN(msg);
-            break;
-        }
-
-        clearSmsDestinations ();
-    } // loop through all the numbers
-
-    if (0 != arrFailed.size ())
-    {
-        this->showMsgBox (QString("Failed to send %1 SMS")
-                                 .arg (arrFailed.size ()));
-        msg = QString("Could not send a text to %1")
-                .arg (arrFailed.join (", "));
-        setStatus (msg);
-    }
-}//MainWindow::sendSMS
-
-void
-MainWindow::sendSMSDone (bool bOk, const QVariantList &params)
-{
-    QString msg;
-    if (!bOk)
-    {
-        msg = QString("Failed to send SMS to %1").arg (params[0].toString());
-    }
-    else
-    {
-        msg = QString("SMS sent to %1").arg (params[0].toString());
-    }
-
-    setStatus (msg);
-}//MainWindow::sendSMSDone
-
 bool
 MainWindow::refreshRegisteredNumbers ()
 {
@@ -1443,187 +935,19 @@ MainWindow::gotAllRegisteredPhones (AsyncTaskToken *token)
         if (ATTS_SUCCESS != token->status) {
             this->showMsgBox ("Failed to retrieve registered phones");
             setStatus ("Failed to retrieve registered phones");
+            Q_WARN ("Failed to retrieve registered phones");
             break;
         }
 
         this->onCallInitiatorsChange (true);
 
+        Q_DEBUG("GV callbacks retrieved.");
         setStatus ("GV callbacks retrieved.");
     } while (0); // End cleanup block (not a loop)
 
     token->deleteLater ();
 }//MainWindow::gotAllRegisteredPhones
 
-bool
-MainWindow::getDialSettings (bool                 &bDialout   ,
-                             GVRegisteredNumber   &gvRegNumber,
-                             CalloutInitiator    *&initiator  )
-{
-    initiator = NULL;
-
-    bool rv = false;
-    do { // Begin cleanup block (not a loop)
-        RegNumData data;
-        if (!modelRegNumber.getAt (indRegPhone, data)) {
-            Q_WARN("Invalid registered phone index");
-            break;
-        }
-
-        gvRegNumber.chType = data.chType;
-        gvRegNumber.strName = data.strName;
-        gvRegNumber.strNumber = data.strDesc;
-        bDialout = (data.type == RNT_Callout);
-        if (bDialout) {
-            initiator = (CalloutInitiator *) data.pCtx;
-        }
-
-        rv = true;
-    } while (0); // End cleanup block (not a loop)
-
-    return (rv);
-}//MainWindow::getDialSettings
-
-void
-MainWindow::retrieveVoicemail (const QString &strVmailLink)
-{
-    AsyncTaskToken *token = NULL;
-    bool rv = false;
-
-    do { // Begin cleanup block (not a loop)
-        if (mapVmail.contains (strVmailLink)) {
-            setStatus ("Playing cached vmail");
-            playVmail (mapVmail[strVmailLink]);
-            rv = true;
-            break;
-        }
-
-        QString strTemplate = QDir::tempPath ()
-                            + QDir::separator ()
-                            + "qgv_XXXXXX.tmp.mp3";
-        QTemporaryFile tempFile (strTemplate);
-        if (!tempFile.open ()) {
-            Q_WARN("Failed to get a temp file name");
-            break;
-        }
-        QString strTemp = QFileInfo (tempFile.fileName ()).absoluteFilePath ();
-        tempFile.close ();
-
-        token = new AsyncTaskToken(this);
-        if (!token) {
-            Q_WARN("Allocation failure");
-            break;
-        }
-
-        rv = connect (token, SIGNAL(completed(AsyncTaskToken*)),
-                      this , SLOT(onVmailDownloaded(AsyncTaskToken*)));
-
-        token->inParams["vmail_link"] = strVmailLink;
-        token->inParams["file_location"] = strTemp;
-        if (!gvApi.getVoicemail (token)) {
-            Q_WARN ("Failed to play Voice mail");
-            break;
-        }
-    } while (0); // End cleanup block (not a loop)
-
-    if (!rv) {
-        if (token) {
-            delete token;
-        }
-    }
-}//MainWindow::retrieveVoicemail
-
-void
-MainWindow::onVmailDownloaded (AsyncTaskToken *token)
-{
-    QString strFilename = token->inParams["file_location"].toString();
-    if (ATTS_SUCCESS == token->status) {
-        QString strVmailLink = token->inParams["vmail_link"].toString();
-        if (!mapVmail.contains (strVmailLink)) {
-            mapVmail[strVmailLink] = strFilename;
-            setStatus ("Voicemail downloaded");
-        } else {
-            setStatus ("Voicemail already existed. Using cached vmail");
-            if (strFilename != mapVmail[strVmailLink]) {
-                QFile::remove (strFilename);
-            }
-        }
-
-        playVmail (mapVmail[strVmailLink]);
-    } else {
-        QFile::remove (strFilename);
-    }
-}//MainWindow::onVmailDownloaded
-
-void
-MainWindow::playVmail (const QString &strFile)
-{
-    do { // Begin cleanup block (not a loop)
-        // Convert it into a file:// url
-        QUrl url = QUrl::fromLocalFile(strFile).toString ();
-
-        qDebug() << "Play vmail file:" << strFile << "Url =" << url;
-
-        createVmailPlayer ();
-        vmailPlayer->setCurrentSource (Phonon::MediaSource(url));
-//        vmailPlayer->setVolume (50);
-        vmailPlayer->play();
-    } while (0); // End cleanup block (not a loop)
-}//MainWindow::playVmail
-
-void
-MainWindow::onVmailPlayerStateChanged(Phonon::State newState,
-                                      Phonon::State /*oldState*/)
-{
-    int value = -1;
-    qDebug() << "Vmail player state changed to" << newState;
-
-    switch (newState) {
-    case Phonon::StoppedState:
-    case Phonon::ErrorState:
-        value = 0;
-        break;
-    case Phonon::PlayingState:
-        value = 1;
-        break;
-    case Phonon::PausedState:
-        value = 2;
-        break;
-    default:
-        Q_WARN("Unknown state!");
-        return;
-    }
-
-    QDeclarativeContext *ctx = this->rootContext();
-    ctx->setContextProperty ("g_vmailPlayerState", value);
-}//MainWindow::onVmailPlayerStateChanged
-
-void
-MainWindow::onSigVmailPlayback (int newstate)
-{
-    if (NULL == vmailPlayer) {
-        qDebug("Vmail object not available.");
-        return;
-    }
-
-    switch(newstate) {
-    case 0:
-        qDebug ("QML asked us to stop vmail");
-        vmailPlayer->stop ();
-        break;
-    case 1:
-        qDebug ("QML asked us to play vmail");
-        vmailPlayer->play ();
-        break;
-    case 2:
-        qDebug ("QML asked us to pause vmail");
-        vmailPlayer->pause ();
-        break;
-    default:
-        qDebug() << "Unknown newstate =" << newstate;
-        break;
-    }
-}//MainWindow::onSigVmailPlayback
-
 void
 MainWindow::onRegPhoneSelectionChange (int index)
 {
@@ -2044,58 +1368,6 @@ MainWindow::onSetContactsModel(QAbstractItemModel *model,
     ctx->setContextProperty ("g_contactsSearchModel", searchModel);
 }//MainWindow::onSetContactsModel
 
-void
-MainWindow::clearSmsDestinations ()
-{
-    do { // Begin cleanup block (not a loop)
-        QObject *pSmsView = getQMLObject ("SmsPage");
-        if (NULL == pSmsView) {
-            Q_WARN("Could not get to SmsPage");
-            break;
-        }
-
-        QMetaObject::invokeMethod (pSmsView, "clearAllDestinations");
-    } while (0); // End cleanup block (not a loop)
-}//MainWindow::clearSmsDestinations
-
-void
-MainWindow::createVmailPlayer()
-{
-    onSigCloseVmail ();
-
-    vmailPlayer = new Phonon::MediaObject(this);
-    Phonon::AudioOutput *audioOutput =
-                new Phonon::AudioOutput(Phonon::MusicCategory, vmailPlayer);
-    Phonon::createPath(vmailPlayer, audioOutput);
-
-    bool rv = connect (
-        vmailPlayer, SIGNAL(stateChanged (Phonon::State, Phonon::State)),
-        this, SLOT(onVmailPlayerStateChanged(Phonon::State, Phonon::State)));
-    Q_ASSERT(rv);
-    if (!rv) { exit(1); }
-    rv = connect (vmailPlayer, SIGNAL(finished ()),
-                  this, SLOT(onVmailPlayerFinished()));
-    Q_ASSERT(rv);
-    if (!rv) { exit(1); }
-}//MainWindow::createVmailPlayer
-
-void
-MainWindow::onVmailPlayerFinished()
-{
-    // Required to make phonon on Maemo work as expected.
-    qDebug("Force stop vmail on finished");
-    vmailPlayer->stop ();
-}//MainWindow::onVmailPlayerFinished
-
-void
-MainWindow::onSigCloseVmail()
-{
-    if (NULL != vmailPlayer) {
-        vmailPlayer->deleteLater ();
-        vmailPlayer = NULL;
-    }
-}//MainWindow::onSigCloseVmail
-
 void
 MainWindow::onRecreateCookieJar()
 {
@@ -2111,7 +1383,7 @@ MainWindow::onTwoStepAuthentication(AsyncTaskToken *token)
 }//MainWindow::onTwoStepAuthentication
 
 void
-MainWindow::onOrientationChanged(OsIndependentOrientation o)
+MainWindow::onOrientationChanged(OsIndependentOrientation /*o*/)
 {
     QObject *pMain = this->rootObject ();
     if (NULL == pMain) {
@@ -2169,151 +1441,3 @@ MainWindow::ensureNwMgr()
 
     return (nwMgr != NULL);
 }//MainWindow::ensureNwMgr
-
-void
-MainWindow::onSigSendLogs()
-{
-    if (!ensureNwMgr ()) {
-        Q_WARN("Failed to ensure NW Mgr");
-        return;
-    }
-
-    QUrl url(LOGS_SERVER "/qgvdial/getLogLocation.py");
-    QNetworkRequest req(url);
-    QNetworkReply *reply = nwMgr->get (req);
-    if (!reply) {
-        return;
-    }
-
-    NwReqTracker *tracker = new NwReqTracker(reply, NULL, NW_REPLY_TIMEOUT,
-                                             true, this);
-    connect(tracker, SIGNAL(sigDone(bool,QByteArray,QNetworkReply*,void*)),
-            this, SLOT(onGetLogLocation(bool,QByteArray,QNetworkReply*,void*)));
-}//MainWindow::onSigSendLogs
-
-void
-MainWindow::onGetLogLocation(bool success, const QByteArray &response,
-                             QNetworkReply *reply, void * /*ctx*/)
-{
-    do { // Begin cleanup block (not a loop)
-        if (!success) {
-            QString strR = reply->readAll ();
-            Q_WARN("Failed to get location to post logs") << strR;
-            break;
-        }
-
-        if (!ensureNwMgr ()) {
-            Q_WARN("Failed to ensure NW Mgr");
-            break;
-        }
-
-        AsyncTaskToken *token = new AsyncTaskToken(this);
-        if (!token) {
-            Q_WARN("Failed to create async token");
-            break;
-        }
-
-        // Flush the logs before trying to send them.
-        qgv_LogFlush();
-
-        //- Collect all the parameters I want to send to myself -//
-        QDateTime dtNow = QDateTime::currentDateTime().toUTC();
-        token->inParams["date"] = dtNow;
-
-        QDomDocument doc("qgvdial Logs");
-        QDomElement root = doc.createElement("Logs");
-        doc.appendChild(root);
-
-        QDomElement paramsTag = doc.createElement("Params");
-        root.appendChild(paramsTag);
-
-        QDomElement dateTag = doc.createElement("Date");
-        paramsTag.appendChild(dateTag);
-
-        QDomText dateTagText = doc.createTextNode(dtNow.toString (Qt::ISODate));
-        dateTag.appendChild(dateTagText);
-
-        QDomElement appVerTag = doc.createElement("Version");
-        paramsTag.appendChild(appVerTag);
-
-        QDomText appVerText = doc.createTextNode("0.3.888");
-        appVerTag.appendChild(appVerText);
-
-        QDomElement osVerTag = doc.createElement("OsVer");
-        paramsTag.appendChild(osVerTag);
-
-        OsDependent &osd = Singletons::getRef().getOSD ();
-        QDomText osVerText = doc.createTextNode(osd.getOSDetails());
-        osVerTag.appendChild(osVerText);
-
-        // Put all the logs into the XML.
-        for (int i = arrLogFiles.count(); i > 0; i--) {
-            QFile fLog(arrLogFiles[i-1]);
-            if (!fLog.open (QIODevice::ReadOnly)) {
-                continue;
-            }
-
-            QDomElement oneLogFile = doc.createElement(arrLogFiles[i-1]);
-            root.appendChild(oneLogFile);
-
-            QDomText t = doc.createTextNode(fLog.readAll ());
-            oneLogFile.appendChild(t);
-        }
-
-        // Post the logs to my server
-        QString postLocation = response;
-        QUrl url(postLocation);
-        QNetworkRequest req(url);
-        req.setHeader (QNetworkRequest::ContentTypeHeader, POST_TEXT);
-
-        reply = nwMgr->post (req, doc.toString().toAscii ());
-        if (!reply) {
-            break;
-        }
-
-        NwReqTracker *tracker = new NwReqTracker(reply, token, NW_REPLY_TIMEOUT,
-                                                 true, this);
-        connect(tracker, SIGNAL(sigDone(bool,QByteArray,QNetworkReply*,void*)),
-                this, SLOT(onLogPosted(bool,QByteArray,QNetworkReply*,void*)));
-    } while (0); // End cleanup block (not a loop)
-}//MainWindow::onGetLogLocation
-
-void
-MainWindow::onLogPosted(bool success, const QByteArray &response,
-                        QNetworkReply *reply, void *ctx)
-{
-    AsyncTaskToken *token = (AsyncTaskToken *) ctx;
-    do { // Begin cleanup block (not a loop)
-        if (!success) {
-            QString strR = reply->readAll ();
-            Q_WARN("Failed to post the logs") << strR;
-            break;
-        }
-
-        // The logs have been posted. Now send an email to me about it.
-        QString strReply = response;
-
-        QUrl url("mailto:yuvraaj@gmail.com");
-        url.addQueryItem ("subject", "Logs");
-
-        OsDependent &osd = Singletons::getRef().getOSD ();
-        QDateTime dt = token->inParams["date"].toDateTime();
-        QString body = QString("Logs captured at %1 \n")
-                                .arg (dt.toUTC ().toString (Qt::ISODate));
-        body += "qgvdial version = 0.3.888 \n";
-        body += QString("OS: %1 \n").arg(osd.getOSDetails());
-        body += QString("Logs are in %1 \n").arg(strReply);
-        url.addQueryItem ("body", body);
-
-        Q_DEBUG(url.toString ());
-
-        if (!QDesktopServices::openUrl (url)) {
-            Q_WARN("Failed to send email about logs");
-            setStatus ("Failed to send email");
-        }
-    } while (0); // End cleanup block (not a loop)
-
-    if (token) {
-        delete token;
-    }
-}//MainWindow::onLogPosted
